#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

from unforward.emailclients.emailclient import EmailClient


class LotusNotesClient(EmailClient):
    """ Extracts originals from lotus notes clients"""
    
    client_type = 'lotusnotes'
    implemented = False
    
    def extract(email):
        pass
    
    def check_match(self, string):
        raise NotImplementedError()
    
    def extract_from_html(self, string):
        raise NotImplementedError()
        


